ModifyOrderRequest

Struct ModifyOrderRequest 

#[non_exhaustive]
pub struct ModifyOrderRequest { pub name: String, pub modifications: Vec<Modification>, pub display_name: String, pub etag: String, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. Name of the order to update.

modifications: Vec<Modification>

Optional. Modifications for an existing Order created by an Offer. Required when Offer based Order is being modified, except for when going from an offer to a public plan.

display_name: String

Optional. Updated display name of the order, leave as empty if you do not want to update current display name.

etag: String

Optional. The weak etag, which can be optionally populated, of the order that this modify request is based on. Validation checking will only happen if the invoker supplies this field.

Implementations

Source

impl ModifyOrderRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = ModifyOrderRequest::new().set_name("example");
pub fn set_modifications<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Modification>,

Sets the value of modifications.

Example
use google_cloud_commerce_consumer_procurement_v1::model::modify_order_request::Modification;
let x = ModifyOrderRequest::new()
    .set_modifications([
        Modification::default()/* use setters */,
        Modification::default()/* use (different) setters */,
    ]);
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = ModifyOrderRequest::new().set_display_name("example");
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = ModifyOrderRequest::new().set_etag("example");