#[non_exhaustive]pub struct ModifyOrderRequest {
pub name: String,
pub modifications: Vec<Modification>,
pub display_name: String,
pub etag: String,
/* private fields */
}Expand description
Request message for ConsumerProcurementService.ModifyOrder.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the order to update.
modifications: Vec<Modification>Optional. Modifications for an existing Order created by an Offer. Required when Offer based Order is being modified, except for when going from an offer to a public plan.
display_name: StringOptional. Updated display name of the order, leave as empty if you do not want to update current display name.
etag: StringOptional. The weak etag, which can be optionally populated, of the order that this modify request is based on. Validation checking will only happen if the invoker supplies this field.
Implementations
Sourceimpl ModifyOrderRequest
impl ModifyOrderRequest
Sourcepub fn set_modifications<T, V>(self, v: T) -> Self
pub fn set_modifications<T, V>(self, v: T) -> Self
Sets the value of modifications.
Example
ⓘ
use google_cloud_commerce_consumer_procurement_v1::model::modify_order_request::Modification;
let x = ModifyOrderRequest::new()
.set_modifications([
Modification::default()/* use setters */,
Modification::default()/* use (different) setters */,
]);Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = ModifyOrderRequest::new().set_display_name("example");Trait Implementations
Sourceimpl Clone for ModifyOrderRequest
impl Clone for ModifyOrderRequest
Sourcefn clone(&self) -> ModifyOrderRequest
fn clone(&self) -> ModifyOrderRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModifyOrderRequest
impl Debug for ModifyOrderRequest
Sourceimpl Default for ModifyOrderRequest
impl Default for ModifyOrderRequest
Sourcefn default() -> ModifyOrderRequest
fn default() -> ModifyOrderRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ModifyOrderRequest
impl Message for ModifyOrderRequest
Sourceimpl PartialEq for ModifyOrderRequest
impl PartialEq for ModifyOrderRequest
Sourcefn eq(&self, other: &ModifyOrderRequest) -> bool
fn eq(&self, other: &ModifyOrderRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ModifyOrderRequest